@@ -5,7 +5,7 @@ from ..weight_models import BetaInBeta
 class BetaInBetaMixture(BaseGaussianMixture):
     def __init__(self, *, x=0, alpha=1, a=1, b=1, mu_prior=None,
                  lambda_prior=1, psi_prior=None, nu_prior=None,
-                 p_method="static", total_iter=1000,
+                 p_method="geometric", total_iter=1000,
                  burn_in=100, subsample_steps=1, rng=None):
         weight_model = BetaInBeta(x=x, alpha=alpha, a=a, b=b,
                                   p_method=p_method, rng=rng)
