@@ -28,10 +28,9 @@ class DirichletProcess(BaseWeight):
         if size is not None:
             if type(size) is not int:
                 raise TypeError("size parameter must be integer or None")
+        self.v = self.v[:0]
         if len(self.d) == 0:
-            self.v = self.rng.beta(a=1, b=self.alpha, size=size)
-            self.w = self.v * np.cumprod(np.concatenate(([1],
-                                                         1 - self.v[:-1])))
+            self.complete(size)
         else:
             a_c = np.bincount(self.d)
             b_c = np.concatenate((np.cumsum(a_c[::-1])[-2::-1], [0]))
@@ -40,7 +39,7 @@ class DirichletProcess(BaseWeight):
                 a_c = a_c[:size]
                 b_c = b_c[:size]
 
-            self.v = self.rng.beta(a=1 + a_c, b=self.alpha + b_c)
+            self.v = self._rng.beta(a=1 + a_c, b=self.alpha + b_c)
             self.w = self.v * np.cumprod(np.concatenate(([1],
                                                          1 - self.v[:-1])))
             if size is not None:
@@ -52,7 +51,7 @@ class DirichletProcess(BaseWeight):
         if len(self.v) < size:
             self.v = np.concatenate(
                 (self.v,
-                 self.rng.beta(a=1, b=self.alpha, size=size - len(self.v))))
+                 self._rng.beta(a=1, b=self.alpha, size=size - len(self.v))))
             self.w = self.v * np.cumprod(np.concatenate(([1],
                                                          1 - self.v[:-1])))
         return self.w
@@ -114,7 +113,7 @@ class DirichletProcess(BaseWeight):
             res -= loggamma(params[0]) + loggamma(params[1])
         return res
 
-    def variational_mean_w(self, j):
+    def variational_mean_w_j(self, j):
         if j >= self.variational_k:
             return 0
         res = 1
@@ -126,7 +125,7 @@ class DirichletProcess(BaseWeight):
                 j].sum()
         return res
 
-    def variational_mode_w(self, j):
+    def variational_mode_w_j(self, j):
         if j >= self.variational_k:
             return 0
         res = 1
